@@ -11,7 +11,6 @@ Author: Anish Acharya
 Contact: anishacharya@utexas.edu
 """
 
-INIT_WEIGHT_STD = 0.01
 np.random.seed(1)
 
 
@@ -30,7 +29,7 @@ class DecGD:
         # ----------------------------------------------------------------------------------
         self.losses = np.zeros(self.param.epochs + 1)
         self.num_samples, self.num_features = self.A.shape
-
+        INIT_WEIGHT_STD = 1 / self.num_features
         self.model.x_estimate = np.random.normal(0, INIT_WEIGHT_STD, size=(self.num_features,))
         self.model.x_estimate = np.tile(self.model.x_estimate, (self.param.n_cores, 1)).T
         # self.model.x_estimate = np.copy(self.model.x)
