@@ -20,10 +20,12 @@ class LogisticRegression:
         x = np.mean(x, axis=1)
         predictions = self.predict(A=A)
 
+        predictions = predictions.reshape(predictions.shape[0], 1)
+
         # Take the error when label=1
-        class1_cost = np.multiply(-y, np.log(predictions))
+        class1_cost = -y * np.log(predictions)
         # Take the error when label=0
-        class2_cost = np.multiply((1 - y), np.log(1 - predictions))
+        class2_cost = (1 - y) * np.log(1 - predictions)
         loss = class1_cost - class2_cost
         loss = loss.sum() / A.shape[0]
 
@@ -62,6 +64,7 @@ class LogisticRegression:
 
     @staticmethod
     def accuracy(predicted_labels, actual_labels):
+        predicted_labels = predicted_labels.reshape(predicted_labels.shape[0], 1)
         diff = predicted_labels - actual_labels
         return 1.0 - (float(np.count_nonzero(diff)) / len(diff))
 
@@ -77,17 +80,19 @@ class LogisticRegression:
 
         else:
             # compute full gradient
-            N = A.shape[1]
+            N = A.shape[0]
+
             # Get Predictions
             predictions = self.predict(A=A)
+            predictions = predictions.reshape(predictions.shape[0], 1)
             gradient = np.dot(A.T, predictions - y)
             gradient /= N
             minus_grad = - gradient
 
         if self.params.regularizer:
-            minus_grad -= self.params.regularizer * x
+            minus_grad -= self.params.regularizer * (x.reshape(x.shape[0], 1))
 
-        return minus_grad
+        return np.squeeze(minus_grad)
 
     # def update_estimate(self, t):
     #     t = int(t)  # to avoid overflow with np.int32
